==> whatpack.py-0.0.2.0.tar.gz: whatpack.py-0.0.2.0/README.md <==

# WhatPack.py

whatpack.py is a Python package that allows you to automate WhatsApp and YouTube tasks in an asynchronous and headless way. It uses asyncpywhatkit and headlesspywhatkit libraries under the hood to provide fast and easy-to-use features. With whatpack.py, you can send messages on WhatsApp without opening the app


![logo.jpg](logo.jpg)



[![Apache License](https://badgen.net/github/license/SigireddyBalasai/whatpack.py)](https://github.com/SigireddyBalasai/whatpack.py/blob/main/LICENSE)
[![Watchers](https://badgen.net/github/watchers/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/watchers)
[![Stars](https://badgen.net/github/stars/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/WhatPack.py/stargazers)
[![Forks](https://badgen.net/github/forks/SigireddyBalasai/whatPack.py)](http://github.com/SigireddyBalasai/whatpack.py/network/members)
[![Tags](https://badgen.net/github/tags/SigireddyBalasai/whatPack.py)](http://github.com/SigireddyBalasai/whatpack.py/tags)
[![Open Issues](https://badgen.net/github/open-issues/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/issues)
[![Closed Issues](https://badgen.net/github/closed-issues/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/issues?q=is%3Aissue+is%3Aclosed)
[![Open PRs](https://badgen.net/github/open-prs/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/pulls)
[![Closed PRs](https://badgen.net/github/closed-prs/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/pulls?q=is%3Apr+is%3Aclosed)
[![Merged PRs](https://badgen.net/github/merged-prs/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/pulls?q=is%3Apr+is%3Amerged)
[![Contributors](https://badgen.net/github/contributors/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/graphs/contributors)
[![Dependabot](https://badgen.net/github/dependabot/SigireddyBalasai/whatPack.py)](https://badgen.net/github/dependabot/SigireddyBalasai/whatPack.py)
[![Code Triagers Badge](https://www.codetriage.com/sigireddybalasai/whatpack.py/badges/users.svg)](https://www.codetriage.com/sigireddybalasai/whatpack.py)
[![Open Source Helpers](https://www.codetriage.com/sigireddybalasai/whatpack.py/badges/users.svg)](https://www.codetriage.com/sigireddybalasai/whatpack.py)
[![Package Dependents](https://badgen.net/github/dependents-pkg/SigireddyBalasai/WhatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/network/dependents)
[![Package Dependencies](https://badgen.net/github/dependents-pkg/SigireddyBalasai/WhatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/network/dependents)


## Contributing

Contributions are always welcome!

See `contributing.md` for ways to get started.

Please adhere to this project's `code of conduct`.


## FAQ

#### I am getting error what should i do

Step 1:use command `pip install --upgrade whatpack.py`

step 2:check examples in examples folder

step 3:open an issue in GitHub

#### it is not working in linux

check if all required dependencies are ready
and open issues 

#### it is not working in windows

check if all required dependencies are ready
and open issues

==> whatpack.py-0.0.5.tar.gz: whatpack.py-0.0.5/README.md <==

# WhatPack.py

whatpack.py is a Python package that allows you to automate WhatsApp and YouTube tasks in an asynchronous and headless way. It uses asyncpywhatkit and headlesspywhatkit libraries under the hood to provide fast and easy-to-use features. With whatpack.py, you can send messages on WhatsApp without opening the app


![logo.jpg](logo.jpg)



[![Apache License](https://badgen.net/github/license/SigireddyBalasai/whatpack.py)](https://github.com/SigireddyBalasai/whatpack.py/blob/main/LICENSE)
[![Watchers](https://badgen.net/github/watchers/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/watchers)
[![Stars](https://badgen.net/github/stars/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/WhatPack.py/stargazers)
[![Forks](https://badgen.net/github/forks/SigireddyBalasai/whatPack.py)](http://github.com/SigireddyBalasai/whatpack.py/network/members)
[![Tags](https://badgen.net/github/tags/SigireddyBalasai/whatPack.py)](http://github.com/SigireddyBalasai/whatpack.py/tags)
[![Open Issues](https://badgen.net/github/open-issues/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/issues)
[![Closed Issues](https://badgen.net/github/closed-issues/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/issues?q=is%3Aissue+is%3Aclosed)
[![Open PRs](https://badgen.net/github/open-prs/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/pulls)
[![Closed PRs](https://badgen.net/github/closed-prs/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/pulls?q=is%3Apr+is%3Aclosed)
[![Merged PRs](https://badgen.net/github/merged-prs/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/pulls?q=is%3Apr+is%3Amerged)
[![Contributors](https://badgen.net/github/contributors/SigireddyBalasai/whatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/graphs/contributors)
[![Dependabot](https://badgen.net/github/dependabot/SigireddyBalasai/whatPack.py)](https://badgen.net/github/dependabot/SigireddyBalasai/whatPack.py)
[![Code Triagers Badge](https://www.codetriage.com/sigireddybalasai/whatpack.py/badges/users.svg)](https://www.codetriage.com/sigireddybalasai/whatpack.py)
[![Open Source Helpers](https://www.codetriage.com/sigireddybalasai/whatpack.py/badges/users.svg)](https://www.codetriage.com/sigireddybalasai/whatpack.py)
[![Package Dependents](https://badgen.net/github/dependents-pkg/SigireddyBalasai/WhatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/network/dependents)
[![Package Dependencies](https://badgen.net/github/dependents-pkg/SigireddyBalasai/WhatPack.py)](https://github.com/SigireddyBalasai/whatpack.py/network/dependents)


## Contributing

Contributions are always welcome!

See `contributing.md` for ways to get started.

Please adhere to this project's `code of conduct`.


## FAQ

#### I am getting error what should i do

Step 1:use command `pip install --upgrade whatpack.py`

step 2:check examples in examples folder

step 3:open an issue in github

#### it is not working in linux

check if all required dependencies are ready
and open issues 

#### it is not working in windows

check if all required dependencies are ready
and open issues
